==> kadu-3.0.tar.bz2: kadu-3.0/plugins/firewall/translations/firewall_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Benachrichtigung-Syntax</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - Nr.-GG, %m - Nachricht</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Suche nach unbekannten Personen im Verzeichnis und zeige Fenster mit seinen Daten.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Schutz vor Chats mit unbekannten</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoriere Konferenzen, wenn alle Teilnehmer unbekannt sind</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Schützt vor Chats mit unbekannten Teilnehmern</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatisch gestellte Frage</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Sende Bestätigung</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Sicheres Senden</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Sicheres Senden einschalten</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Sie müssen jede nachricht bestätitgen, die Sie an diese Personen senden wollen</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log file path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>Ich will etwas</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>Überflutung-Attake mit Smilies!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>DoS-Attake!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Nachricht von unbekannten verworfen.</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK. Und jetzt stell Dich vor ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Benutzer hat die richtige Antwort angegeben!</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Diese Nachricht wurde AUTOMATISCH erstellt!

Ich bin sehr beschäftigt und mag von dummen gelaber nicht gestört werden. Suche jemand anders. Wenn Du aber was von mir willst, scheib einfach &quot;Ich will etwas&quot; (Groß und Kleinschreibung ist egal)</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Sind Sie sicher, dass Sie diese Nachricht senden wollen?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Ja und erlaube es bis zum Chat-Ende</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u schreibt</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Secured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Answer:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u schreibt</translation>
    </message>
</context>
</TS>

==> kadu-4.3.tar.bz2: kadu-4.3/plugins/firewall/translations/firewall_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Benachrichtigung-Syntax</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - Nr.-GG, %m - Nachricht</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Suche nach unbekannten Personen im Verzeichnis und zeige Fenster mit seinen Daten.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Schutz vor Chats mit unbekannten</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoriere Konferenzen, wenn alle Teilnehmer unbekannt sind</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Schützt vor Chats mit unbekannten Teilnehmern</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatisch gestellte Frage</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Sende Bestätigung</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Sicheres Senden</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Sicheres Senden einschalten</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Sie müssen jede nachricht bestätitgen, die Sie an diese Personen senden wollen</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Nachricht wurde gefiltert</translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation>Unbekannter Chat-Versuch</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation>Speichere Chat-Versuche von Unbekannten im Verlauf</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation>Speichere Chat-Versuche von Unbekannten in Log-Datei</translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation>Log-Datei-Pfad</translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Kadu wird die unten eingegebene Frage stellen, wenn jemand Sie anspricht, aber nicht in Ihrer Kontaktliste enthalten ist.</translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation>Ignoriere Chat-Versuche von Unbekannten, wenn unsichtbar oder nicht verfügbar.</translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation>Reaktion auf die richtige Antwort</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Verschiebe zu &quot;Gesichert&quot;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Verschiebe zu &quot;Alle&quot;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Gesichert</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Diese Nachricht wird an eine unbekannte Person gesendet.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Die richtige Antwort auf die Frage oben - Sie können auch Reguläre Ausdrücke benutzen.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Nachricht:</translation>
    </message>
</context>
<context>
    <name>FirewallMessageFilter</name>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>DoS-Attake mit Smilies!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>DoS-Attacke!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Chat mit Unbekanntem wurde verworfen.
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Diese Nachricht wurde AUTOMATISCH generiert!

Ich habe keine Zeit für dumme Chats von unsichtbaren Leuten. Wenn Sie mit mir reden wollen, gehen Sie bitte online oder markieren sich zumindest als beschäftigt.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Chat mit unsichtbaren Unbekanntem ignoriert.
</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Benutzer hat die richtige Antwort angegeben!
</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Sind Sie sicher, dass Sie diese Nachricht senden wollen?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Ja und erlaube es, bis der Chat beendet wird</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nein</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>DATUM/ZEIT :: ID :: NACHRICHT
</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK. Und jetzt stellen Sie sich vor ;-)</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Diese Nachricht wurde AUTOMATISCH erstellt!

Ich bin sehr beschäftigt und mag von nutzlosen Nachrichten nicht gestört werden. Wenn Sie aber etwas von mir wollen, scheiben Sie einfach &quot;Ich will etwas&quot; (Groß und Kleinschreibung ist egal)</translation>
    </message>
    <message>
        <source>I want something</source>
        <translation>Ich will etwas</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u schreibt</translation>
    </message>
</context>
<context>
    <name>FirewallNotificationService</name>
    <message>
        <source>Message was blocked</source>
        <translation>Nachricht wurde geblockt</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>%u schreibt</translation>
    </message>
</context>
</TS>
